from distutils.core import setup

setup(
    name='ss-tools',
    version='0.0.1',
    py_modules=['sstools'],
    author='sspan',
    author_email='sspantiezheng@gmail.com',
    url='http://sspan.org',
    description='a tools set of ss',
)
